@@ -11,78 +11,98 @@ out_file_info = [
         "game": "Chopper I",
         "system": "Arcade",
         "filename": "chopperb.zip",
+        'status': 'good',
         "notes": []
     },
     {
         "game": "Chopper I",
         "system": "Arcade",
         "filename": "legofair.zip",
+        'status': 'good',
         "notes": [3]
     },
     {
         "game": "Fantasy",
         "system": "Arcade",
         "filename": "fantasyj.zip",
+        'status': 'good',
         "notes": []
     },
     {
         "game": "Fantasy",
         "system": "Arcade",
         "filename": "fantasyu.zip",
+        'status': 'good',
         "notes": []
     },
     {
         "game": "Time Soldiers",
         "system": "Arcade",
         "filename": "btlfield.zip",
+        'status': 'good',
         "notes": [3]
     },
     {
         "game": "Time Soldiers",
         "system": "Arcade",
         "filename": "timesold.zip",
+        'status': 'good',
         "notes": [3]
     },
     {
         "game": "Munch Mobile (Joyful Road)",
         "system": "Arcade",
         "filename": "mnchmobl.zip",
+        'status': 'good',
         "notes": []
     },
     {
         "game": "Munch Mobile (Joyful Road)",
         "system": "Arcade",
         "filename": "joyfulr.zip",
+        'status': 'good',
         "notes": []
     },
     {
         "game": "Sasuke vs. Commander",
         "system": "Arcade",
         "filename": "sasuke.zip",
+        'status': 'good',
         "notes": []
     },
     {
         "game": "Ozma Wars",
         "system": "Arcade",
         "filename": "ozmawars.zip",
+        'status': 'playable',
         "notes": [2]
     },
     {
         "game": "Paddle Mania",
         "system": "Arcade",
         "filename": "paddlema.zip",
+        'status': 'playable',
         "notes": [2]
     },
     {
         "game": "Bermuda Triangle",
         "system": "Arcade",
         "filename": "bermudata.zip",
+        'status': 'playable',
+        "notes": [2]
+    },
+    {
+        "game": "World Wars",
+        "system": "Arcade",
+        "filename": "worldwar.zip",
+        "status": "playable",
         "notes": [2]
     },
     {
         "game": "MarvinsMaze",
         "system": "Arcade",
-        "filename": "N/A",
+        "filename": "marvins.zip",
+        'status': 'good',
         "notes": []
     }
 ]
@@ -99,6 +119,7 @@ def extract(bundle_contents):
     out_files.extend(_handle_ozmawars(contents))
     out_files.extend(_handle_paddlemania(contents))
     out_files.extend(_handle_bermuda(contents))
+    out_files.extend(_handle_worldwars(contents))
     out_files.extend(_handle_marvin(contents))
     return out_files
 
@@ -185,6 +206,11 @@ def _handle_chopper(bundle_contents):
     func_map['sp32'] = helpers.equal_split_helper("chopper.sp32_tiles", sp32_file_names)
     func_map['ym2'] = helpers.name_file_helper("chopper.ym2", "kk2.5b")
     func_map['plds'] = helpers.name_file_helper("chopper.plds", "p-a1.8b")
+    ph_files = {
+        'horizon.6h': 0x400,
+        'vertical.7h': 0x400
+    }
+    func_map['placeholders'] = helpers.placeholder_helper(ph_files)
     out_files.append(utils.build_snk_rom("legofair.zip", bundle_contents, func_map))
 
     return out_files
@@ -536,8 +562,6 @@ def _handle_bermuda(bundle_contents):
     ]
     func_map['sp32'] = helpers.equal_split_helper('WorldWars.sp32', sp32_filenames)
     ph_files = {
-        'l.1d': 0x1000,
-        'l.2d': 0x1000,
         'horizon.5h': 0x400,
         'vertical.7h': 0x400
     }
@@ -562,6 +586,72 @@ def _handle_bermuda(bundle_contents):
 
     return out_files
 
+
+def _handle_worldwars(bundle_contents):
+    '''Extract World Wars'''
+    out_files = []
+    # World Wars Common
+    func_map = {}
+    bg_filenames = [
+        "ww11.1e",
+        "ww12.1d",
+        "ww13.1b",
+        "ww14.1a"
+    ]
+    func_map['bg'] = helpers.equal_split_helper('WorldWars.bg', bg_filenames)
+    sp_filenames = [
+        "ww10.3g",
+        "ww9.3e",
+        "ww8.3d",
+        "ww7.3b"
+    ]
+    func_map['sp'] = helpers.equal_split_helper('WorldWars.sp', sp_filenames)
+    sp32_filenames = [
+        "ww21.7p",
+        "ww22.7s",
+        "ww19.8h",
+        "ww20.8k",
+        "ww15.8m",
+        "ww16.8n",
+        "ww17.8p",
+        "ww18.8s"
+    ]
+    func_map['sp32'] = helpers.equal_split_helper('WorldWars.sp32', sp32_filenames)
+    ph_files = {
+        'horizon.5h': 0x400,
+        'vertical.7h': 0x400
+    }
+    func_map['ph'] = helpers.placeholder_helper(ph_files)
+    logger.info("Processing World Wars common files...")
+    common_file_map = helpers.process_rom_files(bundle_contents, func_map)
+
+    # WORLDWAR
+    func_map = {}
+    func_map['maincpu'] = helpers.name_file_helper("WorldWars.0.z80", "ww4.4p")
+    func_map['sub'] = helpers.name_file_helper("WorldWars.1.z80", "ww5.8p")
+    func_map['audiocpu'] = helpers.name_file_helper("WorldWars.2.z80", "ww3.7k")
+    func_map['tx'] = helpers.name_file_helper("WorldWars.tx", "ww6.3a")
+    func_map['common'] = helpers.existing_files_helper(common_file_map)
+    pal_filenames = [
+        "2.1l",
+        "1.1k",
+        "3.2l"
+    ]
+    func_map['pal'] = utils.simple_palette_helper('WorldWars.pal', pal_filenames)
+    adpcm_filenames = [
+        "p4.5e",
+        "p5.5g"
+    ]
+    func_map['adpcm'] = helpers.equal_split_helper('WorldWars.adpcm', adpcm_filenames)
+    mame_name = "worldwar.zip"
+    logger.info(f"Building {mame_name}...")
+    out_files.append(
+        {'filename': mame_name, 'contents': helpers.build_rom(bundle_contents, func_map)}
+    )
+    logger.info(f"Extracted {mame_name}.")
+
+    return out_files
+
 def _handle_marvin(bundle_contents):
     '''Extract Marvin's Maze'''
     out_files = []
